<?php
/**
 * Ce fichier contient l'ensemble des fonctions de service spécifiques à une ou plusieurs collections.
 *
 * @package SPIP\EZMASHUP\EZCOLLECTION\SERVICE
 */
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

// -----------------------------------------------------------------------
// ------------------------ COLLECTION SERVICES --------------------------
// -----------------------------------------------------------------------

/**
 * Récupère les configuration des services.
 * Il est possible de filtrer la liste avec le critère facultatif categorie ou plugin.
 *
 * @param array $conditions    Conditions à appliquer au select
 * @param array $filtres       Tableau des critères de filtrage additionnels à appliquer au select.
 * @param array $configuration Configuration de la collection utile pour savoir quelle fonction appeler pour
 *                             construire chaque filtre.
 *
 * @return array Tableau des subdivisions et par défaut des codes alternatifs et de la liste des pays.
 */
function feeds_collectionner(array $conditions, array $filtres, array $configuration) : array {
	// Initialisation de la collection
	$feeds = [];

	// Récupérer la liste des feeds (filtrée ou pas).
	// -- Tous le champs sauf l'indicateur d'activité (le champ est toujours exclu).
	$from = 'spip_feeds';
	// -- Tous le champs sauf les labels par langue et la date de mise à jour.
	$description_table = sql_showtable($from, true);
	$champs = array_keys($description_table['field']);
	$select = array_diff($champs, ['is_active', 'target_options', 'mapping', 'include', 'maj']);

	// -- Initialisation du where: le feed doit être actif.
	$where = [
		'is_active=' . sql_quote('oui')
	];
	// -- Si il y a des critères additionnels on complète le where en conséquence.
	if ($conditions) {
		$where = array_merge($where, $conditions);
	}

	// -- Lecture de la table
	$feeds_actifs = sql_allfetsel($select, $from, $where);

	// Il faut maintenant vérifier que les feeds sont peuplés et rajouter les informations associer
	include_spip('inc/ezmashup_dataset_target');
	foreach ($feeds_actifs as $_feed) {
		// Recherche des informations de consignation de peuplement
		if ($consigne = dataset_target_informer($_feed['plugin'], $_feed['feed_id'])) {
			$feeds[$_feed['feed_id']] = $_feed;
			$feeds[$_feed['feed_id']]['tags'] = json_decode($feeds[$_feed['feed_id']]['tags'], true);
			$feeds[$_feed['feed_id']]['records'] = $consigne['records'];
		}
	}

	return $feeds;
}

/**
 * Calcule la condition du filtre `categorie` pour lequel il est possible de passer une liste d'identifiants séparés
 * par une virgule.
 *
 * @param string $valeur Valeur du critère `category`.
 *
 * @return string La condition SQL sur le champ `category`.
 */
function feeds_conditionner_categorie(string $valeur) : string {
	$condition = '';
	if ($valeur) {
		if (strpos($valeur, ',') === false) {
			// Une seule catégorie
			$condition = 'category=' . sql_quote($valeur);
		} else {
			// Une liste de pays séparés par des virgules
			$categories = explode(',', $valeur);
			$condition = sql_in('category', $categories);
		}
	}

	return $condition;
}

// -----------------------------------------------------------------------
// ----------------- SERVICES NON LIES A UNE COLLECTION ------------------
// -----------------------------------------------------------------------
